@@ -43,6 +43,7 @@ import glob
 import re
 import logging
 import time
+import traceback
 from datetime import datetime
 import xml.etree.ElementTree as ET
 from functools import wraps
@@ -495,8 +496,9 @@ class EndpointPipelinePublisher:
             pipeline_endpoint = PipelineEndpoint.get(workspace=self.ws, name=pipeline_endpoint_name)
         except Exception as e:
             s = str(e)
-            if not "BadRequest" in s:
-                raise Exception(e)
+            print(e)
+            print(traceback.format_exc())
+            print(sys.exc_info()[2])
 
         if not pipeline_endpoint:
             pipeline_endpoint = PipelineEndpoint.publish(workspace=self.ws,
